初始化项目,由ModelHub XC社区提供模型

Model: zhangjiefu/GPU-Qwen3-0.6-V2
Source: Original Platform
This commit is contained in:
ModelHub XC
2026-06-08 05:17:15 +08:00
commit 0aa240b22a
12 changed files with 852 additions and 0 deletions

52
.gitattributes vendored Normal file
View File

@@ -0,0 +1,52 @@
*.7z filter=lfs diff=lfs merge=lfs -text
*.arrow filter=lfs diff=lfs merge=lfs -text
*.bz2 filter=lfs diff=lfs merge=lfs -text
*.ftz filter=lfs diff=lfs merge=lfs -text
*.gz filter=lfs diff=lfs merge=lfs -text
*.h5 filter=lfs diff=lfs merge=lfs -text
*.joblib filter=lfs diff=lfs merge=lfs -text
*.lfs.* filter=lfs diff=lfs merge=lfs -text
*.msgpack filter=lfs diff=lfs merge=lfs -text
*.onnx filter=lfs diff=lfs merge=lfs -text
*.ot filter=lfs diff=lfs merge=lfs -text
*.parquet filter=lfs diff=lfs merge=lfs -text
*.pb filter=lfs diff=lfs merge=lfs -text
*.pt filter=lfs diff=lfs merge=lfs -text
*.pth filter=lfs diff=lfs merge=lfs -text
*.rar filter=lfs diff=lfs merge=lfs -text
saved_model/**/* filter=lfs diff=lfs merge=lfs -text
*.tar.* filter=lfs diff=lfs merge=lfs -text
*.tflite filter=lfs diff=lfs merge=lfs -text
*.tgz filter=lfs diff=lfs merge=lfs -text
*.xz filter=lfs diff=lfs merge=lfs -text
*.zip filter=lfs diff=lfs merge=lfs -text
*.zstandard filter=lfs diff=lfs merge=lfs -text
*.tfevents* filter=lfs diff=lfs merge=lfs -text
*.db* filter=lfs diff=lfs merge=lfs -text
*.ark* filter=lfs diff=lfs merge=lfs -text
**/*ckpt*data* filter=lfs diff=lfs merge=lfs -text
**/*ckpt*.meta filter=lfs diff=lfs merge=lfs -text
**/*ckpt*.index filter=lfs diff=lfs merge=lfs -text
*.safetensors filter=lfs diff=lfs merge=lfs -text
*.ckpt filter=lfs diff=lfs merge=lfs -text
*.gguf* filter=lfs diff=lfs merge=lfs -text
*.ggml filter=lfs diff=lfs merge=lfs -text
*.llamafile* filter=lfs diff=lfs merge=lfs -text
*.pt2 filter=lfs diff=lfs merge=lfs -text
*.mlmodel filter=lfs diff=lfs merge=lfs -text
*.npy filter=lfs diff=lfs merge=lfs -text
*.npz filter=lfs diff=lfs merge=lfs -text
*.pickle filter=lfs diff=lfs merge=lfs -text
*.pkl filter=lfs diff=lfs merge=lfs -text
*.tar filter=lfs diff=lfs merge=lfs -text
*.wasm filter=lfs diff=lfs merge=lfs -text
*.zst filter=lfs diff=lfs merge=lfs -text
*tfevents* filter=lfs diff=lfs merge=lfs -text
merges.txt filter=lfs diff=lfs merge=lfs -text
tokenizer.json filter=lfs diff=lfs merge=lfs -text
pytorch_model-00002.bin filter=lfs diff=lfs merge=lfs -text
pytorch_model-00001.bin filter=lfs diff=lfs merge=lfs -text

52
README.md Normal file
View File

@@ -0,0 +1,52 @@
---
frameworks:
- Pytorch
license: Apache License 2.0
tags: []
tasks:
- text-generation
#model-type:
##如 gpt、phi、llama、chatglm、baichuan 等
#- gpt
#domain:
##如 nlp、cv、audio、multi-modal
#- nlp
#language:
##语言代码列表 https://help.aliyun.com/document_detail/215387.html?spm=a2c4g.11186623.0.0.9f8d7467kni6Aa
#- cn
#metrics:
##如 CIDEr、Blue、ROUGE 等
#- CIDEr
#tags:
##各种自定义,包括 pretrained、fine-tuned、instruction-tuned、RL-tuned 等训练方法和其他
#- pretrained
#tools:
##如 vllm、fastchat、llamacpp、AdaSeq 等
#- vllm
---
### 当前模型的贡献者未提供更加详细的模型介绍。模型文件和权重,可浏览“模型文件”页面获取。
#### 您可以通过如下git clone命令或者ModelScope SDK来下载模型
SDK下载
```bash
#安装ModelScope
pip install modelscope
```
```python
#SDK模型下载
from modelscope import snapshot_download
model_dir = snapshot_download('zhangjiefu/GPU-Qwen3-0.6-V2')
```
Git下载
```
#Git模型下载
git clone https://www.modelscope.cn/zhangjiefu/GPU-Qwen3-0.6-V2.git
```
<p style="color: lightgrey;">如果您是本模型的贡献者,我们邀请您根据<a href="https://modelscope.cn/docs/ModelScope%E6%A8%A1%E5%9E%8B%E6%8E%A5%E5%85%A5%E6%B5%81%E7%A8%8B%E6%A6%82%E8%A7%88" style="color: lightgrey; text-decoration: underline;">模型贡献文档</a>,及时完善模型卡片内容。</p>

60
config.json Normal file
View File

@@ -0,0 +1,60 @@
{
"architectures": [
"Qwen3ForCausalLM"
],
"attention_bias": false,
"attention_dropout": 0.0,
"bos_token_id": 151643,
"dtype": "bfloat16",
"eos_token_id": 151645,
"head_dim": 128,
"hidden_act": "silu",
"hidden_size": 1024,
"initializer_range": 0.02,
"intermediate_size": 3072,
"layer_types": [
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention",
"full_attention"
],
"max_position_embeddings": 40960,
"max_window_layers": 28,
"model_type": "qwen3",
"num_attention_heads": 16,
"num_hidden_layers": 28,
"num_key_value_heads": 8,
"rms_norm_eps": 1e-06,
"rope_scaling": null,
"rope_theta": 1000000,
"sliding_window": null,
"tie_word_embeddings": true,
"transformers_version": "4.57.1",
"use_cache": true,
"use_sliding_window": false,
"vocab_size": 151936
}

1
configuration.json Normal file
View File

@@ -0,0 +1 @@
{"framework":"Pytorch","task":"text-generation"}

13
generation_config.json Normal file
View File

@@ -0,0 +1,13 @@
{
"bos_token_id": 151643,
"do_sample": true,
"eos_token_id": [
151645,
151643
],
"pad_token_id": 151643,
"temperature": 0.6,
"top_k": 20,
"top_p": 0.95,
"transformers_version": "4.57.1"
}

BIN
merges.txt (Stored with Git LFS) Normal file

Binary file not shown.

3
pytorch_model-00001.bin Normal file
View File

@@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:e9bf28b1ac47e2e8db442037033ddf6b146c1acbc7e6629c7c9407277c2490d4
size 1072629584

3
pytorch_model-00002.bin Normal file
View File

@@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:234c88a0ff7635e15479ce0a5e504d656f867b9cafb6fe99d518c8080081b424
size 430737682

View File

@@ -0,0 +1,318 @@
{
"metadata": {
"total_size": 1433.625
},
"weight_map": {
"model.embed_tokens.weight": "pytorch_model-00001.bin",
"model.layers.0.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.0.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.0.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.0.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.0.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.0.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.0.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.0.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.0.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.0.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.0.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.1.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.1.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.1.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.1.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.1.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.1.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.1.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.1.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.1.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.1.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.1.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.2.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.2.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.2.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.2.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.2.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.2.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.2.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.2.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.2.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.2.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.2.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.3.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.3.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.3.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.3.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.3.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.3.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.3.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.3.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.3.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.3.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.3.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.4.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.4.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.4.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.4.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.4.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.4.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.4.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.4.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.4.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.4.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.4.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.5.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.5.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.5.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.5.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.5.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.5.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.5.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.5.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.5.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.5.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.5.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.6.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.6.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.6.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.6.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.6.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.6.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.6.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.6.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.6.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.6.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.6.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.7.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.7.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.7.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.7.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.7.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.7.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.7.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.7.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.7.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.7.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.7.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.8.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.8.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.8.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.8.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.8.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.8.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.8.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.8.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.8.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.8.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.8.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.9.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.9.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.9.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.9.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.9.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.9.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.9.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.9.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.9.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.9.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.9.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.10.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.10.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.10.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.10.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.10.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.10.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.10.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.10.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.10.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.10.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.10.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.11.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.11.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.11.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.11.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.11.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.11.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.11.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.11.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.11.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.11.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.11.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.12.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.12.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.12.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.12.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.12.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.12.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.12.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.12.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.12.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.12.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.12.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.13.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.13.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.13.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.13.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.13.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.13.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.13.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.13.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.13.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.13.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.13.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.14.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.14.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.14.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.14.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.14.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.14.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.14.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.14.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.14.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.14.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.14.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.15.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.15.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.15.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.15.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.15.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.15.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.15.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.15.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.15.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.15.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.15.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.16.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.16.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.16.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.16.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.16.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.16.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.16.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.16.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.16.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.16.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.16.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.17.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.17.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.17.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.17.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.17.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.17.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.17.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.17.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.17.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.17.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.17.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.18.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.18.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.18.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.18.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.18.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.18.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.18.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.18.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.18.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.18.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.18.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.19.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.19.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.19.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.19.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.19.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.19.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.19.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.19.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.19.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.19.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.19.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.20.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.20.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.20.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.20.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.20.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.20.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.20.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.20.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.20.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.20.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.20.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.21.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.21.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.21.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.21.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.21.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.21.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.21.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.21.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.21.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.21.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.21.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.22.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.22.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.22.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.22.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.22.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.22.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.22.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.22.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.22.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.22.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.22.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.23.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.23.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.23.self_attn.v_proj.weight": "pytorch_model-00001.bin",
"model.layers.23.self_attn.o_proj.weight": "pytorch_model-00001.bin",
"model.layers.23.self_attn.q_norm.weight": "pytorch_model-00001.bin",
"model.layers.23.self_attn.k_norm.weight": "pytorch_model-00001.bin",
"model.layers.23.mlp.gate_proj.weight": "pytorch_model-00001.bin",
"model.layers.23.mlp.up_proj.weight": "pytorch_model-00001.bin",
"model.layers.23.mlp.down_proj.weight": "pytorch_model-00001.bin",
"model.layers.23.input_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.23.post_attention_layernorm.weight": "pytorch_model-00001.bin",
"model.layers.24.self_attn.q_proj.weight": "pytorch_model-00001.bin",
"model.layers.24.self_attn.k_proj.weight": "pytorch_model-00001.bin",
"model.layers.24.self_attn.v_proj.weight": "pytorch_model-00002.bin",
"model.layers.24.self_attn.o_proj.weight": "pytorch_model-00002.bin",
"model.layers.24.self_attn.q_norm.weight": "pytorch_model-00002.bin",
"model.layers.24.self_attn.k_norm.weight": "pytorch_model-00002.bin",
"model.layers.24.mlp.gate_proj.weight": "pytorch_model-00002.bin",
"model.layers.24.mlp.up_proj.weight": "pytorch_model-00002.bin",
"model.layers.24.mlp.down_proj.weight": "pytorch_model-00002.bin",
"model.layers.24.input_layernorm.weight": "pytorch_model-00002.bin",
"model.layers.24.post_attention_layernorm.weight": "pytorch_model-00002.bin",
"model.layers.25.self_attn.q_proj.weight": "pytorch_model-00002.bin",
"model.layers.25.self_attn.k_proj.weight": "pytorch_model-00002.bin",
"model.layers.25.self_attn.v_proj.weight": "pytorch_model-00002.bin",
"model.layers.25.self_attn.o_proj.weight": "pytorch_model-00002.bin",
"model.layers.25.self_attn.q_norm.weight": "pytorch_model-00002.bin",
"model.layers.25.self_attn.k_norm.weight": "pytorch_model-00002.bin",
"model.layers.25.mlp.gate_proj.weight": "pytorch_model-00002.bin",
"model.layers.25.mlp.up_proj.weight": "pytorch_model-00002.bin",
"model.layers.25.mlp.down_proj.weight": "pytorch_model-00002.bin",
"model.layers.25.input_layernorm.weight": "pytorch_model-00002.bin",
"model.layers.25.post_attention_layernorm.weight": "pytorch_model-00002.bin",
"model.layers.26.self_attn.q_proj.weight": "pytorch_model-00002.bin",
"model.layers.26.self_attn.k_proj.weight": "pytorch_model-00002.bin",
"model.layers.26.self_attn.v_proj.weight": "pytorch_model-00002.bin",
"model.layers.26.self_attn.o_proj.weight": "pytorch_model-00002.bin",
"model.layers.26.self_attn.q_norm.weight": "pytorch_model-00002.bin",
"model.layers.26.self_attn.k_norm.weight": "pytorch_model-00002.bin",
"model.layers.26.mlp.gate_proj.weight": "pytorch_model-00002.bin",
"model.layers.26.mlp.up_proj.weight": "pytorch_model-00002.bin",
"model.layers.26.mlp.down_proj.weight": "pytorch_model-00002.bin",
"model.layers.26.input_layernorm.weight": "pytorch_model-00002.bin",
"model.layers.26.post_attention_layernorm.weight": "pytorch_model-00002.bin",
"model.layers.27.self_attn.q_proj.weight": "pytorch_model-00002.bin",
"model.layers.27.self_attn.k_proj.weight": "pytorch_model-00002.bin",
"model.layers.27.self_attn.v_proj.weight": "pytorch_model-00002.bin",
"model.layers.27.self_attn.o_proj.weight": "pytorch_model-00002.bin",
"model.layers.27.self_attn.q_norm.weight": "pytorch_model-00002.bin",
"model.layers.27.self_attn.k_norm.weight": "pytorch_model-00002.bin",
"model.layers.27.mlp.gate_proj.weight": "pytorch_model-00002.bin",
"model.layers.27.mlp.up_proj.weight": "pytorch_model-00002.bin",
"model.layers.27.mlp.down_proj.weight": "pytorch_model-00002.bin",
"model.layers.27.input_layernorm.weight": "pytorch_model-00002.bin",
"model.layers.27.post_attention_layernorm.weight": "pytorch_model-00002.bin",
"model.norm.weight": "pytorch_model-00002.bin",
"lm_head.weight": "pytorch_model-00002.bin"
}
}

105
qwen-zh-basic.json Normal file
View File

@@ -0,0 +1,105 @@
[
{"instruction": "CUDA的全称是", "input": "", "output": "CUDA的全称是Compute Unified Device Architecture。"},
{"instruction": "什么是数据并行性?", "input": "", "output": "数据并行性是指将计算任务围绕数据进行重组,使多个独立的计算可并行执行以提升整体效率的特性。比如将彩色图像转灰度图时,每个像素的转换计算相互独立,可由不同线程同时完成,能充分利用海量数据的并行处理潜力。"},
{"instruction": "CUDA C程序的整体执行流程是怎样的", "input": "", "output": "CUDA C程序执行起始于主机CPU的串行代码当调用核函数并行设备代码会在设备GPU上生成大量线程组成的网格来执行核函数逻辑所有核函数对应的线程网格执行完毕后程序会回到主机端继续执行串行代码部分场景下还可实现CPU与GPU执行的重叠以提升整体效率。"},
{"instruction": "CUDA中的核函数是什么", "input": "", "output": "核函数是CUDA C中标记有__global__关键字的特殊函数它规定了设备端并行执行的代码逻辑所有线程都会执行相同的核函数代码是实现异构并行计算中设备端并行任务的核心载体只能由主机代码启动执行支持动态并行的架构除外。"},
{"instruction": "CUDA核函数的函数声明关键字有哪些各自的作用是什么", "input": "", "output": "CUDA核函数相关的声明关键字主要有三个__global__标识的是可在主机端调用、在设备端执行的核函数是实现大规模并行计算的核心函数__device__标识的是仅能在设备端执行且只能被核函数或其他设备函数调用的函数__host__标识的是仅在主机端执行且仅能被主机函数调用的函数无特殊关键字的函数默认是__host__函数。"},
{"instruction": "CUDA中cudaMalloc函数的作用和参数要求是什么", "input": "", "output": "cudaMalloc是CUDA提供的用于在设备全局内存中分配存储空间的API函数它的第一个参数需传入指向设备内存指针的地址且要强制转换为void**类型用于接收分配的设备内存地址第二个参数是要分配的内存字节数其设计逻辑与C语言malloc函数相近便于C程序员快速上手设备内存管理。"},
{"instruction": "CUDA中cudaMemcpy函数的功能和参数构成是什么", "input": "", "output": "cudaMemcpy是CUDA中用于在主机内存和设备内存之间传输数据的API函数它共有四个参数分别是目标内存指针、源内存指针、要传输的字节数以及数据传输的方向标识如主机到设备、设备到主机等通过该函数可实现主机与设备间的数据交互为核函数执行提供数据支持。"},
{"instruction": "CUDA中的blockDim内置变量代表什么", "input": "", "output": "blockDim是CUDA核函数可访问的内置只读变量它是一个包含x、y、z三个无符号整数字段的结构体用于表示每个线程块中各维度的线程数量其值由核函数启动时的执行配置参数决定帮助线程确定自身在块内的相对位置。"},
{"instruction": "CUDA中的threadIdx内置变量的作用是什么", "input": "", "output": "threadIdx是CUDA核函数内的内置只读变量同样包含x、y、z三个字段用于标识线程在所属线程块内的唯一坐标线程可通过该变量区分自身与块内其他线程进而确定自己要处理的数据区域是实现线程数据分工的关键变量。"},
{"instruction": "CUDA中的blockIdx内置变量的含义是什么", "input": "", "output": "blockIdx是CUDA核函数可访问的内置只读变量包含x、y、z三个字段用于标识线程所在的线程块在整个网格中的唯一坐标同一线程块内的所有线程拥有相同的blockIdx值结合threadIdx可实现线程在整个网格中的全局定位。"},
{"instruction": "CUDA核函数启动时的执行配置参数有什么作用", "input": "", "output": "CUDA核函数启动时的执行配置参数需写在<<<>>> 符号内,主要分为两部分,第一部分用于指定网格中线程块的维度(数量),第二部分用于指定每个线程块内的线程维度(数量),通过这两个参数可灵活控制设备端并行执行的线程规模和组织形式,适配不同的数据处理需求。"},
{"instruction": "为什么CUDA核函数中常需要添加边界检查的条件判断", "input": "", "output": "因为核函数启动的线程数量通常是线程块大小的整数倍,而待处理数据的规模不一定能被线程块大小整除,为了避免超出数据范围的无效计算,需要在核函数中通过条件判断(如检查线程对应的全局索引是否小于数据总长度)过滤掉多余的线程操作,保证计算结果的正确性。"},
{"instruction": "CUDA中的设备全局内存和主机内存有什么本质区别", "input": "", "output": "CUDA的设备全局内存是GPU专属的存储空间由GPU硬件直接管理和访问其访问延迟和带宽特性与GPU架构适配而主机内存是CPU可直接访问的系统内存二者物理上相互独立数据无法直接跨区域访问需通过cudaMemcpy等API函数完成数据传输。"},
{"instruction": "CUDA核函数的执行网格是如何组织的", "input": "", "output": "CUDA核函数执行时会生成由大量线程构成的网格网格采用两级层级结构顶层是由一个或多个线程块组成的一维、二维或三维数组底层每个线程块又是由一个或多个线程组成的一维、二维或三维数组所有线程块尺寸一致线程会按照该层级结构完成数据的并行处理。"},
{"instruction": "什么是CUDA中的SPMD并行编程模式", "input": "", "output": "CUDA采用的SPMD即单程序多数据并行编程模式指所有线程都会执行同一核函数代码但会基于自身的blockIdx和threadIdx等内置变量对不同的数据片段进行处理以此实现大规模数据的并行计算是GPU海量并行能力的核心实现模式。"},
{"instruction": "CUDA中cudaFree函数的作用是什么", "input": "", "output": "cudaFree是CUDA提供的用于释放设备全局内存空间的API函数其参数为指向要释放的设备内存的指针调用该函数可将之前通过cudaMalloc分配的设备内存归还给系统避免设备内存泄漏保障程序长期运行的稳定性。"},
{"instruction": "CUDA中线程块的维度设置有什么限制", "input": "", "output": "CUDA中每个线程块的总线程数有明确上限通常不超过1024同时可灵活将线程块组织为一维、二维或三维结构只要三个维度的线程数量乘积不超过总线程数上限即可且维度选择通常会匹配数据的维度特性以方便线程与数据的映射。"},
{"instruction": "如何将CUDA线程映射到二维数据如图像像素", "input": "", "output": "可将CUDA网格和线程块都设置为二维结构线程通过blockIdx.x、blockDim.x和threadIdx.x计算出自身对应的二维数据水平方向索引通过blockIdx.y、blockDim.y和threadIdx.y计算出垂直方向索引再结合数据的行列长度做边界检查即可实现线程与二维数据的精准映射。"},
{"instruction": "CUDA中的__syncthreads()函数有什么作用?", "input": "", "output": "__syncthreads()是CUDA中的屏障同步函数当线程块内的某个线程调用该函数时会在此处暂停执行直到该线程块内所有线程都到达这个同步点之后才能继续执行后续代码它是实现线程块内线程间协作和数据同步的关键手段。"},
{"instruction": "使用__syncthreads()有哪些注意事项?", "input": "", "output": "使用__syncthreads()时,必须保证线程块内所有线程都有机会执行到该同步点,不能出现在部分线程执行、部分线程不执行的分支逻辑中,否则会导致未执行到同步点的线程永远等待,已执行到的线程也无法继续推进,引发程序死锁或功能异常。"},
{"instruction": "什么是CUDA的透明可扩展性", "input": "", "output": "CUDA的透明可扩展性指同一CUDA程序无需修改代码就能在不同硬件规格的GPU设备上运行且能根据设备的执行资源数量自动适配执行速度在低配置GPU上低速运行、高配置GPU上高速运行实现了程序跨设备的灵活适配。"},
{"instruction": "CUDA中线程块的资源分配是如何进行的", "input": "", "output": "CUDA中线程块会以整体为单位被分配到流式多处理器SM上执行一个SM可同时分配多个线程块具体数量受SM的资源限制如寄存器数量、共享内存大小等只有当SM能为线程块提供足够的执行资源时该线程块才能在其上启动执行。"},
{"instruction": "如何查询CUDA设备的属性信息", "input": "", "output": "可通过CUDA提供的cudaGetDeviceCount函数获取系统中可用的CUDA设备数量再通过cudaGetDeviceProperties函数传入设备属性结构体指针和设备编号即可获取对应设备的详细属性包括SM数量、最大线程块尺寸、寄存器数量等关键信息。"},
{"instruction": "CUDA设备属性中maxThreadsPerBlock的含义是什么", "input": "", "output": "maxThreadsPerBlock是CUDA设备属性中的一个字段用于表示该设备上每个线程块所能容纳的最大线程数量不同架构的设备该数值可能不同它是开发者设置线程块尺寸时需要遵守的重要限制条件。"},
{"instruction": "CUDA中的warp是什么", "input": "", "output": "warp即线程束是CUDA设备中线程调度的基本单位通常一个warp包含32个连续的线程这些线程会按照SIMD单指令多数据模式执行即同一时刻所有线程执行相同的指令不同线程仅处理不同的数据。"},
{"instruction": "CUDA中warp的调度机制是怎样的", "input": "", "output": "CUDA中SM会将分配到的线程块划分为多个warpSM的硬件执行单元会优先选择无指令依赖、可立即执行的warp进行调度当某个warp因等待内存访问或指令执行延迟而无法推进时SM会切换到其他就绪的warp执行以此隐藏延迟提升硬件资源利用率。"},
{"instruction": "什么是CUDA的延迟容忍隐藏机制", "input": "", "output": "CUDA的延迟容忍机制是指当某个warp因等待长延迟操作如全局内存访问、长周期算术运算而暂停时SM会调度其他就绪的warp在硬件执行单元上执行将原本的等待时间转化为有效计算时间从而提升整体的执行吞吐量充分利用硬件资源。"},
{"instruction": "CUDA中SM的核心组成部分有哪些", "input": "", "output": "CUDA中流式多处理器SM包含多个流处理器SP用于执行算术运算指令还配备了指令获取与分发单元、共享内存、寄存器文件等核心组件同时支持多个线程块和warp的调度与执行是GPU并行计算的核心硬件单元。"},
{"instruction": "为什么CUDA需要为SM分配大量线程", "input": "", "output": "为SM分配大量线程是为了提供足够多的可调度warp当部分warp因等待长延迟操作而无法执行时SM能快速切换到其他就绪warp通过延迟容忍机制充分利用硬件执行单元避免硬件资源闲置保障GPU的高执行吞吐量。"},
{"instruction": "CUDA中线程块的执行顺序是怎样的", "input": "", "output": "CUDA中线程块的执行顺序是不确定的不同线程块之间没有固定的执行先后关系也无法通过代码控制其执行顺序这种设计保障了程序的透明可扩展性使得程序能在不同资源规模的GPU上灵活适配。"},
{"instruction": "在图像模糊核函数中,如何处理边界像素的计算?", "input": "", "output": "在图像模糊核函数中,对于靠近图像边界的像素,其对应的模糊邻域会超出图像有效范围,此时需要通过条件判断检查邻域内像素的坐标是否在图像的宽高范围内,仅对有效范围内的像素进行加权求和,对超出范围的像素则忽略,以此保证边界像素计算结果的正确性。"},
{"instruction": "CUDA中gridDim内置变量的作用是什么", "input": "", "output": "gridDim是CUDA核函数内的内置只读变量包含x、y、z三个字段用于表示整个线程网格中各维度的线程块数量其值由核函数启动时的执行配置参数确定线程可通过该变量知晓网格的整体规模辅助完成全局数据的定位。"},
{"instruction": "CUDA中线程块的尺寸选择需要考虑哪些因素", "input": "", "output": "CUDA线程块尺寸选择需考虑多方面因素包括设备支持的最大线程块线程数、SM的资源限制如寄存器和共享内存容量、数据的维度特性同时要尽量保证线程块尺寸是warp大小的整数倍以提升硬件执行的效率。"},
{"instruction": "什么是CUDA的零开销线程调度", "input": "", "output": "CUDA的零开销线程调度指SM在切换不同warp执行时不会产生额外的硬件开销通过硬件层面的高效调度机制在warp之间快速切换执行上下文从而在隐藏延迟的同时不增加程序的执行负担保障GPU的高执行效率。"},
{"instruction": "CUDA中多维度线程块和网格的优势是什么", "input": "", "output": "CUDA中多维度线程块和网格的优势在于能更好地匹配多维度数据的结构比如处理二维图像时采用二维线程块和网格可让线程的坐标与图像的行列坐标直接对应简化线程与数据的映射逻辑提升代码的可读性和开发效率。"},
{"instruction": "CUDA中线程同步为什么仅能在块内实现", "input": "", "output": "CUDA中线程同步仅能在块内实现是因为不同线程块可能会被分配到不同的SM上执行而不同SM之间的同步机制实现复杂且会大幅降低程序的可扩展性块内同步则可依托SM的硬件资源高效完成同时保障了程序的透明可扩展性。"},
{"instruction": "为什么内存访问效率对CUDA程序性能至关重要", "input": "", "output": "GPU的计算能力极强而全局内存的访问延迟高、带宽有限若内存访问效率低下会导致大量计算单元因等待数据而闲置程序性能会受限于内存带宽而非计算能力因此提升内存访问效率是释放GPU计算潜力、保障程序高性能的关键。"},
{"instruction": "什么是计算-全局内存访问比?", "input": "", "output": "计算-全局内存访问比指程序中浮点计算操作的数量与全局内存访问操作数量的比值该比值越高说明程序对计算资源的利用率越高越不容易受限于全局内存带宽比值过低时程序会呈现内存受限的特性难以发挥GPU的计算优势。"},
{"instruction": "CUDA中的寄存器内存有什么特点", "input": "", "output": "CUDA中寄存器是线程私有的高速片上内存访问延迟极低、带宽极高核函数中的自动标量变量默认会分配到寄存器中但其容量有限每个线程可使用的寄存器数量受硬件限制过量使用会导致SM能同时调度的线程数减少。"},
{"instruction": "CUDA中的共享内存有什么特性", "input": "", "output": "CUDA中共享内存是线程块内线程共享的片上内存访问速度远快于全局内存其生命周期与线程块一致线程块内的所有线程都可读写共享内存常用于存储线程块内线程需要共同访问的数据以减少全局内存访问次数。"},
{"instruction": "CUDA中的常量内存有什么作用", "input": "", "output": "CUDA中的常量内存是用于存储只读全局数据的内存区域其数据可被所有线程访问且硬件会对常量内存的访问进行缓存优化当多个线程访问相同的常量数据时能大幅降低全局内存的访问压力提升数据读取效率适合存储核函数执行所需的固定输入参数。"},
{"instruction": "CUDA中的全局内存有什么优缺点", "input": "", "output": "CUDA全局内存的优点是容量大可存储大规模的输入输出数据且其数据可被所有线程和主机端访问缺点是访问延迟高、带宽有限未优化的全局内存访问会成为程序性能的瓶颈需要通过各种优化手段提升其访问效率。"},
{"instruction": "什么是数据局部性?", "input": "", "output": "数据局部性指程序在执行过程中,倾向于重复访问近期使用过的数据或相邻数据的特性,包括时间局部性(同一数据被多次访问)和空间局部性(相邻数据被连续访问),利用数据局部性可通过片上内存缓存数据,减少全局内存访问,提升程序性能。"},
{"instruction": "什么是CUDA中的分块tiling技术", "input": "", "output": "CUDA中的分块技术是将大规模数据划分为多个小尺寸的“数据块”tile让每个线程块仅处理一个数据块线程块会先将对应数据块从全局内存加载到共享内存再基于共享内存完成计算以此提升数据访问的局部性减少全局内存访问次数。"},
{"instruction": "分块技术能提升CUDA程序性能的核心原因是什么", "input": "", "output": "分块技术提升性能的核心原因是利用了数据局部性,将需要重复访问的数据缓存到高速的共享内存中,替代对高延迟、低带宽的全局内存的频繁访问;同时分块后的数据访问模式更易实现全局内存的合并访问,进一步提升内存访问效率。"},
{"instruction": "矩阵乘法中使用分块技术的优势是什么?", "input": "", "output": "矩阵乘法中使用分块技术,可将输入矩阵划分为多个子矩阵块,线程块先将子矩阵块加载到共享内存,后续计算可复用共享内存中的数据,大幅减少对全局内存的访问次数;同时合理的分块能实现全局内存的合并访问,提升内存带宽利用率,进而显著提升矩阵乘法的执行效率。"},
{"instruction": "CUDA核函数中自动数组变量会被分配到哪里", "input": "", "output": "CUDA核函数中的自动数组变量通常不会分配到寄存器中而是会被分配到全局内存这会导致其访问延迟大幅增加且每个线程都会拥有该数组的私有副本因此在核函数中应尽量避免使用自动数组变量可通过共享内存等方式替代。"},
{"instruction": "CUDA中共享内存的作用域和生命周期是怎样的", "input": "", "output": "CUDA中共享内存的作用域为单个线程块即只有同一线程块内的线程才能访问该块对应的共享内存其生命周期与线程块的执行周期一致线程块启动时共享内存被分配线程块执行完毕后共享内存被释放数据无法跨线程块共享。"},
{"instruction": "CUDA中常量内存的作用域和生命周期是怎样的", "input": "", "output": "CUDA中常量内存的作用域覆盖整个应用的所有核函数和所有线程即所有网格、所有线程块的线程都可访问常量内存数据其生命周期贯穿整个应用的执行过程数据会一直保留直到应用结束可用于存储多个核函数都需要的固定配置参数。"},
{"instruction": "为什么CUDA程序中要谨慎使用寄存器", "input": "", "output": "虽然寄存器访问速度极快但CUDA中每个SM的寄存器总量有限若核函数中每个线程使用过多寄存器会导致SM能同时调度的线程块数量减少进而减少可调度的warp数量降低延迟容忍能力最终可能导致程序性能下降。"},
{"instruction": "分块矩阵乘法中为什么需要添加边界检查?", "input": "", "output": "分块矩阵乘法中,当矩阵的尺寸无法被分块的尺寸整除时,部分数据块会超出矩阵的有效范围,此时需要通过边界检查判断要访问的矩阵元素是否在合法的行列范围内,仅对有效范围内的元素进行加载和计算,以此保证矩阵乘法结果的正确性。"},
{"instruction": "CUDA中全局内存的访问延迟和带宽与片上内存有多大差距", "input": "", "output": "CUDA中全局内存的访问延迟通常是片上寄存器和共享内存的数百倍其带宽也远低于片上内存寄存器和共享内存的聚合访问带宽比全局内存高至少两个数量级因此减少全局内存访问、多用片上内存是提升程序性能的关键。"},
{"instruction": "什么是CUDA中的“边角转换corner turning”技术", "input": "", "output": "边角转换是CUDA中利用共享内存优化内存访问模式的技术当算法需要按行访问数据但该模式无法实现全局内存合并访问时可先将数据按合并访问的模式加载到共享内存再在共享内存中按行访问数据以此兼顾内存访问效率和算法逻辑。"},
{"instruction": "CUDA中共享内存的容量限制会带来什么影响", "input": "", "output": "CUDA中每个SM的共享内存容量有限若分块尺寸过大单个线程块所需的共享内存会超出硬件限制导致SM无法同时分配多个线程块同时共享内存不足也会限制分块技术的应用效果无法充分利用数据局部性提升性能。"},
{"instruction": "CUDA中内存资源如何限制并行性", "input": "", "output": "CUDA中寄存器、共享内存等片上内存资源总量有限若核函数中每个线程或线程块占用的内存资源过多会导致SM能同时调度的线程数和线程块数减少可用于延迟容忍的warp数量也随之降低硬件资源利用率下降最终限制了程序的整体并行能力。"},
{"instruction": "如何动态调整CUDA核函数的共享内存用量", "input": "", "output": "可通过在核函数中使用extern __shared__关键字声明无尺寸的共享内存数组然后在核函数启动时将共享内存的实际尺寸作为第三个执行配置参数传入以此实现共享内存用量的动态调整适配不同的硬件资源和算法需求。"},
{"instruction": "什么是CUDA中的全局内存合并访问", "input": "", "output": "CUDA中的全局内存合并访问指warp内的线程访问连续的全局内存地址此时硬件会将这些分散的访问请求合并为一个或少量的内存请求大幅提升全局内存的访问带宽利用率若访问地址不连续则会产生大量独立请求降低访问效率。"},
{"instruction": "在CUDA的行优先存储矩阵中如何实现全局内存的合并访问", "input": "", "output": "在CUDA行优先存储的矩阵中当线程按列方向访问矩阵元素时warp内线程的访问地址是连续的可实现全局内存的合并访问而按行方向访问时线程访问地址间隔较大无法实现合并访问因此可通过调整访问模式或使用共享内存优化来提升访问效率。"},
{"instruction": "什么是CUDA中的内存通道和内存银行", "input": "", "output": "CUDA全局内存的DRAM系统会采用通道和银行的并行组织形式通道是连接处理器和内存控制器的总线多个通道可并行传输数据每个通道下又会划分多个内存银行银行可并行响应访问请求二者共同构成了内存的并行访问架构。"},
{"instruction": "内存通道和银行如何提升CUDA的内存访问带宽", "input": "", "output": "多个内存通道可并行传输数据提升数据传输的整体带宽每个通道下的多个内存银行可并行响应不同的访问请求将内存访问的延迟进行重叠提升内存访问的吞吐量二者结合可充分发挥DRAM的并行访问能力满足GPU海量线程的内存访问需求。"},
{"instruction": "为什么CUDA程序需要足够多的并行线程来充分利用内存带宽", "input": "", "output": "因为内存通道和银行的并行访问能力需要大量的并发访问请求才能充分激活,若并行线程数量不足,内存访问请求会集中在少数通道或银行,导致部分硬件资源闲置,无法充分利用内存的并行访问带宽,进而限制程序的整体性能。"},
{"instruction": "什么是CUDA中的控制流发散", "input": "", "output": "CUDA中的控制流发散指同一warp内的线程因执行不同的分支逻辑如if-else、循环条件不同而产生的执行路径分歧此时硬件会为不同分支的线程分批次执行增加了指令执行的总周期降低了warp的执行效率。"},
{"instruction": "控制流发散对CUDA程序性能有什么影响", "input": "", "output": "控制流发散会导致同一warp内的线程无法同步执行硬件需为不同分支的线程分别执行指令增加了指令执行的总次数和总周期降低了warp的执行吞吐量严重的控制流发散会大幅削弱GPU的并行计算优势导致程序性能下降。"},
{"instruction": "CUDA中如何减少控制流发散的影响", "input": "", "output": "可通过调整算法逻辑让warp内的线程尽量执行相同的分支路径对于边界条件导致的控制流发散可通过提前过滤无效线程或调整数据尺寸减少发散的warp数量同时可利用共享内存等机制将发散逻辑转化为统一的计算逻辑。"},
{"instruction": "CUDA中动态资源分配的含义是什么", "input": "", "output": "CUDA中的动态资源分配指SM会根据核函数的资源需求动态将寄存器、共享内存等资源分配给不同的线程块线程块所需资源少则SM可同时分配更多线程块所需资源多则分配的线程块数量减少以此实现资源的灵活调度和高效利用。"},
{"instruction": "CUDA中寄存器资源的分配会如何影响并行性", "input": "", "output": "CUDA中每个SM的寄存器总量固定若核函数中每个线程占用的寄存器数量过多SM能同时分配的线程块数量会减少导致SM内的活跃线程数和warp数降低延迟容忍能力下降硬件资源利用率不足最终降低了程序的整体并行执行能力。"},
{"instruction": "什么是CUDA中的“性能悬崖”", "input": "", "output": "CUDA中的“性能悬崖”指当核函数的资源使用量如寄存器、共享内存超过某个临界值时SM能同时调度的线程块数量会突然大幅减少导致活跃warp数骤降程序的执行性能出现断崖式下跌是开发者在性能调优时需要重点规避的现象。"},
{"instruction": "CUDA中共享内存的使用会如何影响并行性", "input": "", "output": "CUDA中每个SM的共享内存容量有限若线程块所需的共享内存过多SM能同时分配的线程块数量会减少活跃线程数和warp数也随之降低但合理使用共享内存可减少全局内存访问提升程序整体性能因此需平衡共享内存用量与并行性的关系。"},
{"instruction": "什么是CUDA中的线程粒度", "input": "", "output": "CUDA中的线程粒度指单个线程所承担的计算任务量线程粒度小则单个线程任务少需要的线程总数多线程粒度大则单个线程任务多需要的线程总数少合适的线程粒度需结合硬件资源和算法特性来确定。"},
{"instruction": "调整CUDA线程粒度的优势是什么", "input": "", "output": "调整线程粒度可减少线程间的冗余计算,比如让单个线程处理多个相邻的输出元素,可减少全局内存的重复访问和指令的冗余执行;同时合适的线程粒度能平衡线程数量与硬件资源的匹配度,提升硬件资源利用率和程序整体性能。"},
{"instruction": "矩阵乘法中提升线程粒度的具体方式是什么?", "input": "", "output": "矩阵乘法中可让单个线程计算多个相邻的输出矩阵元素,比如原本一个线程计算一个元素,调整为一个线程计算同一行或同一列的多个元素,这样可减少输入矩阵数据的冗余加载,降低全局内存访问次数,同时减少指令执行的总数量。"},
{"instruction": "CUDA中warp内线程的执行特性是什么", "input": "", "output": "CUDA中同一warp内的线程会严格遵循SIMD执行模式即同一时刻所有线程执行相同的指令只是操作的数据不同当warp内线程出现控制流发散时会分批次执行不同分支直到所有分支执行完毕再统一进入后续指令。"},
{"instruction": "为什么CUDA中要尽量避免warp内的控制流发散", "input": "", "output": "因为warp内的控制流发散会导致线程分批次执行不同分支增加了指令执行的总周期降低了warp的执行效率大量的控制流发散会使GPU的并行计算优势无法充分发挥程序的整体性能会受到显著影响。"},
{"instruction": "CUDA中归约算法为什么会出现控制流发散", "input": "", "output": "归约算法中随着迭代的进行参与计算的线程数量会逐渐减少部分线程会因不满足计算条件而进入空闲状态导致同一warp内的线程出现执行路径分歧进而产生控制流发散影响归约算法的执行效率。"},
{"instruction": "如何优化归约算法中的控制流发散?", "input": "", "output": "可通过调整归约的迭代逻辑让参与计算的线程尽量集中在连续的warp中比如从后往前进行归约计算让前半部分warp的线程参与计算、后半部分线程闲置减少warp内的分支分歧同时可通过循环展开等方式进一步降低控制流发散的影响。"},
{"instruction": "CUDA中的Occupancy占用率指什么", "input": "", "output": "CUDA中的Occupancy指SM上实际活跃的线程数与SM最大可支持线程数的比值它反映了SM硬件资源的利用程度Occupancy越高说明SM内的活跃warp数越多延迟容忍能力越强硬件资源利用率也越高。"},
{"instruction": "影响CUDA Occupancy的因素有哪些", "input": "", "output": "影响CUDA Occupancy的因素包括每个线程占用的寄存器数量、每个线程块占用的共享内存大小、设备支持的最大线程块数量、每个线程块的线程数等这些因素共同决定了SM能同时调度的线程块数和线程数进而影响Occupancy。"},
{"instruction": "CUDA中如何计算核函数的Occupancy", "input": "", "output": "可通过NVIDIA提供的CUDA Occupancy Calculator工具输入核函数的线程块尺寸、每个线程的寄存器用量、每个线程块的共享内存用量等信息工具会根据目标设备的硬件参数计算出该核函数在设备上的Occupancy数值辅助开发者进行性能调优。"},
{"instruction": "什么是CUDA中的内存银行冲突", "input": "", "output": "CUDA中共享内存会被划分为多个独立的内存银行当多个线程同时访问同一内存银行的不同地址时会产生内存银行冲突导致访问请求被串行化处理降低共享内存的访问带宽若线程访问不同银行的地址则可实现并行访问。"},
{"instruction": "如何避免CUDA中的共享内存银行冲突", "input": "", "output": "可通过调整数据的存储布局比如在数据数组中添加填充元素让线程的访问地址映射到不同的内存银行也可调整线程的访问模式让同一warp内的线程访问不同银行的地址以此避免或减少内存银行冲突提升共享内存访问效率。"},
{"instruction": "CUDA中全局内存的对齐访问有什么要求", "input": "", "output": "早期CUDA设备对全局内存的访问有严格的对齐要求要求访问的地址必须是16字节或32字节的整数倍现代CUDA设备虽放松了对齐要求但对齐的访问模式仍能获得更高的访问效率因此在编程时应尽量保证全局内存访问的地址对齐。"},
{"instruction": "IEEE 754浮点数格式由哪几部分组成", "input": "", "output": "IEEE 754浮点数格式由符号位、指数位和尾数位三部分组成符号位用于表示数的正负指数位采用偏移编码方式表示数的量级尾数位用于表示数的精度部分通过这三部分的组合可表示不同范围和精度的浮点数。"},
{"instruction": "什么是浮点数的规格化表示?", "input": "", "output": "浮点数的规格化表示是指将尾数部分调整为1.xxxxx的形式1为隐含位不占用尾数位空间通过这种表示方式可使每个浮点数的表示形式唯一同时能最大化尾数位的有效位数提升浮点数的表示精度。"},
{"instruction": "什么是浮点数的偏移excess编码", "input": "", "output": "浮点数的偏移编码是指数位的编码方式即给指数的真实值加上一个偏移量通常为2^(n1)1n为指数位的位数得到指数的编码值这种编码方式可将有符号的指数值转换为无符号整数方便硬件进行大小比较。"},
{"instruction": "什么是浮点数的非规格化denormal", "input": "", "output": "浮点数的非规格化数是指当指数位全为0时的特殊表示形式此时尾数不再隐含1而是以0.xxxxx的形式存在用于表示非常接近0的极小数值填补了规格化数在0附近的表示间隙提升了小数的表示精度。"},
{"instruction": "浮点数的精度和什么因素相关?", "input": "", "output": "浮点数的精度主要与尾数位的位数相关尾数位的位数越多浮点数能表示的有效数字就越多精度也就越高单精度浮点数尾数位为23位双精度浮点数尾数位为52位因此双精度浮点数的精度远高于单精度。"},
{"instruction": "什么是浮点数的ULP", "input": "", "output": "ULP即最后一位的单位指相邻两个可表示浮点数之间的差值它是衡量浮点数表示精度和计算误差的重要指标ULP值越小说明浮点数的表示精度越高计算结果的误差也越小。"},
{"instruction": "什么是浮点数运算的准确度?", "input": "", "output": "浮点数运算的准确度指浮点数运算结果与真实数学结果的接近程度通常用运算结果的最大ULP误差来衡量若运算的最大ULP误差不超过0.5,则说明该运算具有较高的准确度,能满足大部分数值计算的需求。"},
{"instruction": "浮点数运算中的舍入误差是如何产生的?", "input": "", "output": "浮点数运算中的舍入误差源于浮点数的有限精度表示,当运算结果的尾数位数超过浮点数尾数位的最大长度时,需要对超出部分进行舍入处理,这会导致运算结果与真实值之间产生偏差,进而形成舍入误差。"},
{"instruction": "为什么并行归约的顺序会影响浮点数的计算结果?", "input": "", "output": "因为浮点数的加法不满足严格的结合律,不同的加法顺序会产生不同的舍入误差,并行归约会改变传统串行归约的加法顺序,导致最终的累加结果与串行结果存在偏差,这种偏差的大小与数据的分布和运算顺序密切相关。"},
{"instruction": "如何提升并行归约的浮点数计算精度?", "input": "", "output": "可通过对数据进行预排序让数值相近的数据先进行累加减少大数吞小数的现象也可采用补偿求和算法如Kahan求和算法通过记录累加过程中的误差来修正最终结果同时可选择更高精度的浮点数类型如双精度进行计算。"},
{"instruction": "什么是NaN和无穷大", "input": "", "output": "NaN即非数值是IEEE 754格式中的特殊值当指数位全为1且尾数位不全为0时表示NaN用于表示无效的浮点运算结果如0/0、∞-∞无穷大是指数位全为1且尾数位全为0时的特殊值分为正无穷和负无穷用于表示超出浮点数表示范围的数值如大数除以0。"},
{"instruction": "什么是信号NaNSNaN和安静NaNQNaN", "input": "", "output": "信号NaN和安静NaN是NaN的两种类型信号NaN的尾数位最高位为0当运算中出现信号NaN时会触发硬件异常常用于调试未初始化的数据安静NaN的尾数位最高位为1运算中出现安静NaN时不会触发异常仅会传播NaN值常用于表示无效数据。"},
{"instruction": "什么是数值算法的稳定性?", "input": "", "output": "数值算法的稳定性指算法在执行过程中,对输入数据的微小扰动或计算过程中的舍入误差的抵抗能力,稳定的算法会使这些误差在计算过程中不会被放大,最终结果仍能保持较高的准确度;不稳定的算法则会放大误差,导致结果严重偏离真实值。"},
{"instruction": "高斯消元法为什么会出现数值不稳定性?", "input": "", "output": "传统高斯消元法在消元过程中若主元当前列的最大元素过小用其作为除数会导致后续计算的舍入误差被大幅放大进而影响最终解的准确度当主元为0时传统高斯消元法甚至无法继续执行因此会出现数值不稳定性。"},
{"instruction": "什么是高斯消元法的选主元pivoting技术", "input": "", "output": "高斯消元法的选主元技术是指在每一步消元前选择当前列中绝对值最大的元素作为主元并通过行交换将其换到主对角线位置再进行消元计算这种技术可避免因主元过小或为0导致的数值不稳定性提升算法的数值稳定性。"},
{"instruction": "浮点数的表示范围由什么因素决定?", "input": "", "output": "浮点数的表示范围主要由指数位的位数决定指数位的位数越多浮点数能表示的量级范围就越大可表示的极大数和极小数的范围也就越广单精度浮点数指数位为8位双精度为11位因此双精度浮点数的表示范围远大于单精度。"},
{"instruction": "什么是浮点数的下溢和上溢?", "input": "", "output": "浮点数的下溢是指计算结果的绝对值小于浮点数能表示的最小规格化数此时会自动转换为非规格化数或0浮点数的上溢是指计算结果的绝对值大于浮点数能表示的最大数此时会转换为无穷大这两种情况都会导致计算结果的精度损失或失效。"},
{"instruction": "为什么并行算法的数值结果可能与串行算法不同?", "input": "", "output": "一方面是因为浮点数运算不满足严格的结合律和交换律,并行算法改变了运算的顺序,导致舍入误差的累积方式与串行算法不同;另一方面是并行算法可能采用了不同的计算策略,这些策略会引入新的数值误差,最终导致结果存在差异。"},
{"instruction": "单精度和双精度浮点数的主要区别是什么?", "input": "", "output": "单精度浮点数占用4字节空间指数位8位、尾数位23位可表示的数值范围约为10^(38)到10^38有效数字约6-7位双精度浮点数占用8字节空间指数位11位、尾数位52位可表示的数值范围约为10^(308)到10^308有效数字约15-16位双精度在范围和精度上均远超单精度。"},
{"instruction": "什么是数值计算中的大数吞小数现象?", "input": "", "output": "数值计算中的大数吞小数现象是指当一个极大的浮点数与一个极小的浮点数相加时,由于浮点数的尾数位精度有限,极小的数会被极大的数“吞噬”,相加结果等于极大的数,导致小数的贡献完全丢失,这种现象会严重影响累加类计算的精度。"},
{"instruction": "CUDA中local memory的作用是什么", "input": "", "output": "CUDA中的local memory是线程私有的内存空间用于存储自动数组变量或超出寄存器容量的自动变量其本质是全局内存的一部分访问延迟较高仅在寄存器不足时被编译器分配使用应尽量避免依赖local memory以保证性能。"},
{"instruction": "CUDA中不同内存类型的访问延迟从低到高排序是什么", "input": "", "output": "CUDA中不同内存类型的访问延迟从低到高排序为寄存器 < 共享内存 < 常量内存(缓存命中) < 全局内存(缓存命中) < local memory < 全局内存(缓存未命中),该排序反映了各类内存的硬件实现和访问机制差异。"}
]

BIN
tokenizer.json (Stored with Git LFS) Normal file

Binary file not shown.

239
tokenizer_config.json Normal file
View File

@@ -0,0 +1,239 @@
{
"add_bos_token": false,
"add_prefix_space": false,
"added_tokens_decoder": {
"151643": {
"content": "<|endoftext|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": true
},
"151644": {
"content": "<|im_start|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": true
},
"151645": {
"content": "<|im_end|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": true
},
"151646": {
"content": "<|object_ref_start|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": true
},
"151647": {
"content": "<|object_ref_end|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": true
},
"151648": {
"content": "<|box_start|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": true
},
"151649": {
"content": "<|box_end|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": true
},
"151650": {
"content": "<|quad_start|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": true
},
"151651": {
"content": "<|quad_end|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": true
},
"151652": {
"content": "<|vision_start|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": true
},
"151653": {
"content": "<|vision_end|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": true
},
"151654": {
"content": "<|vision_pad|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": true
},
"151655": {
"content": "<|image_pad|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": true
},
"151656": {
"content": "<|video_pad|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": true
},
"151657": {
"content": "<tool_call>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": false
},
"151658": {
"content": "</tool_call>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": false
},
"151659": {
"content": "<|fim_prefix|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": false
},
"151660": {
"content": "<|fim_middle|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": false
},
"151661": {
"content": "<|fim_suffix|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": false
},
"151662": {
"content": "<|fim_pad|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": false
},
"151663": {
"content": "<|repo_name|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": false
},
"151664": {
"content": "<|file_sep|>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": false
},
"151665": {
"content": "<tool_response>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": false
},
"151666": {
"content": "</tool_response>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": false
},
"151667": {
"content": "<think>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": false
},
"151668": {
"content": "</think>",
"lstrip": false,
"normalized": false,
"rstrip": false,
"single_word": false,
"special": false
}
},
"additional_special_tokens": [
"<|im_start|>",
"<|im_end|>",
"<|object_ref_start|>",
"<|object_ref_end|>",
"<|box_start|>",
"<|box_end|>",
"<|quad_start|>",
"<|quad_end|>",
"<|vision_start|>",
"<|vision_end|>",
"<|vision_pad|>",
"<|image_pad|>",
"<|video_pad|>"
],
"bos_token": "<|im_start|>",
"chat_template": "{%- if tools %}\n {{- '<|im_start|>system\\n' }}\n {%- if messages[0].role == 'system' %}\n {{- messages[0].content + '\\n\\n' }}\n {%- endif %}\n {{- \"# Tools\\n\\nYou may call one or more functions to assist with the user query.\\n\\nYou are provided with function signatures within <tools></tools> XML tags:\\n<tools>\" }}\n {%- for tool in tools %}\n {{- \"\\n\" }}\n {{- tool | tojson }}\n {%- endfor %}\n {{- \"\\n</tools>\\n\\nFor each function call, return a json object with function name and arguments within <tool_call></tool_call> XML tags:\\n<tool_call>\\n{\\\"name\\\": <function-name>, \\\"arguments\\\": <args-json-object>}\\n</tool_call><|im_end|>\\n\" }}\n{%- else %}\n {%- if messages[0].role == 'system' %}\n {{- '<|im_start|>system\\n' + messages[0].content + '<|im_end|>\\n' }}\n {%- endif %}\n{%- endif %}\n{%- set ns = namespace(multi_step_tool=true, last_query_index=messages|length - 1) %}\n{%- for message in messages[::-1] %}\n {%- set index = (messages|length - 1) - loop.index0 %}\n {%- if ns.multi_step_tool and message.role == \"user\" and message.content is string and not(message.content.startswith('<tool_response>') and message.content.endswith('</tool_response>')) %}\n {%- set ns.multi_step_tool = false %}\n {%- set ns.last_query_index = index %}\n {%- endif %}\n{%- endfor %}\n{%- for message in messages %}\n {%- if message.content is string %}\n {%- set content = message.content %}\n {%- else %}\n {%- set content = '' %}\n {%- endif %}\n {%- if (message.role == \"user\") or (message.role == \"system\" and not loop.first) %}\n {{- '<|im_start|>' + message.role + '\\n' + content + '<|im_end|>' + '\\n' }}\n {%- elif message.role == \"assistant\" %}\n {%- set reasoning_content = '' %}\n {%- if message.reasoning_content is string %}\n {%- set reasoning_content = message.reasoning_content %}\n {%- else %}\n {%- if '</think>' in content %}\n {%- set reasoning_content = content.split('</think>')[0].rstrip('\\n').split('<think>')[-1].lstrip('\\n') %}\n {%- set content = content.split('</think>')[-1].lstrip('\\n') %}\n {%- endif %}\n {%- endif %}\n {%- if loop.index0 > ns.last_query_index %}\n {%- if loop.last or (not loop.last and reasoning_content) %}\n {{- '<|im_start|>' + message.role + '\\n<think>\\n' + reasoning_content.strip('\\n') + '\\n</think>\\n\\n' + content.lstrip('\\n') }}\n {%- else %}\n {{- '<|im_start|>' + message.role + '\\n' + content }}\n {%- endif %}\n {%- else %}\n {{- '<|im_start|>' + message.role + '\\n' + content }}\n {%- endif %}\n {%- if message.tool_calls %}\n {%- for tool_call in message.tool_calls %}\n {%- if (loop.first and content) or (not loop.first) %}\n {{- '\\n' }}\n {%- endif %}\n {%- if tool_call.function %}\n {%- set tool_call = tool_call.function %}\n {%- endif %}\n {{- '<tool_call>\\n{\"name\": \"' }}\n {{- tool_call.name }}\n {{- '\", \"arguments\": ' }}\n {%- if tool_call.arguments is string %}\n {{- tool_call.arguments }}\n {%- else %}\n {{- tool_call.arguments | tojson }}\n {%- endif %}\n {{- '}\\n</tool_call>' }}\n {%- endfor %}\n {%- endif %}\n {{- '<|im_end|>\\n' }}\n {%- elif message.role == \"tool\" %}\n {%- if loop.first or (messages[loop.index0 - 1].role != \"tool\") %}\n {{- '<|im_start|>user' }}\n {%- endif %}\n {{- '\\n<tool_response>\\n' }}\n {{- content }}\n {{- '\\n</tool_response>' }}\n {%- if loop.last or (messages[loop.index0 + 1].role != \"tool\") %}\n {{- '<|im_end|>\\n' }}\n {%- endif %}\n {%- endif %}\n{%- endfor %}\n{%- if add_generation_prompt %}\n {{- '<|im_start|>assistant\\n' }}\n {%- if enable_thinking is defined and enable_thinking is false %}\n {{- '<think>\\n\\n</think>\\n\\n' }}\n {%- endif %}\n{%- endif %}",
"clean_up_tokenization_spaces": false,
"eos_token": "<|im_end|>",
"errors": "replace",
"model_max_length": 131072,
"pad_token": "<|endoftext|>",
"split_special_tokens": false,
"tokenizer_class": "Qwen2Tokenizer",
"unk_token": null
}